Crate yarns

Crate yarns 

Functions

concat
Concatenates two strings.
contains
Returns wether a given String contains the given Substring.
head
Gets the first char of a string, and returns it as string.
len
Returns the length of the utf-8 representation of a string.
read
Shortcut for simple binding of user input to an immutable String.
substr
Returns a new string starting at the index provided in the second argument, going the length provided as the third argument.